# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ncompare']

package_data = \
{'': ['*']}

install_requires = \
['colorama>=0.4.6',
 'h5netcdf>=1.4.1,<2.0.0',
 'h5py>=3.12.1,<4.0.0',
 'netCDF4>=1.6.4',
 'numpy>=1.26.0',
 'openpyxl>=3.1.2',
 'xarray>=2023.9']

entry_points = \
{'console_scripts': ['ncompare = ncompare.console:main']}

setup_kwargs = {
    'name': 'ncompare',
    'version': '1.13.0',
    'description': 'Compare the structure of two NetCDF files at the command line',
    'long_description': '# ncompare\n_____\n\n<a href="https://www.repostatus.org/#active" target="_blank">\n    <img src="https://www.repostatus.org/badges/latest/active.svg" alt="Project Status: Active – The project has reached a stable, usable state and is being actively developed">\n</a>\n<a href="https://codecov.io/gh/nasa/ncompare">\n <img src="https://codecov.io/gh/nasa/ncompare/graph/badge.svg?token=5JJUNA1Z6S" alt="Code coverage">\n</a>\n<a href="https://ncompare.readthedocs.io/en/latest/?badge=latest">\n    <img src="https://readthedocs.org/projects/ncompare/badge/?version=latest" alt="Documentation Status">\n</a>\n<a href="https://pypi.org/project/ncompare/" target="_blank">\n    <img src="https://img.shields.io/pypi/pyversions/ncompare.svg" alt="Python Versions">\n</a>\n<a href="https://pypi.org/project/ncompare" target="_blank">\n    <img src="https://img.shields.io/pypi/v/ncompare?color=%2334D058label=pypi%20package" alt="Package version">\n</a>\n<a href="https://mypy-lang.org/" target="_blank">\n    <img src="https://www.mypy-lang.org/static/mypy_badge.svg" alt="Mypy checked">\n</a>\n<a href="https://github.com/nasa/ncompare/issues" target="_blank">\n    <img src="https://img.shields.io/badge/contributions-welcome-brightgreen.svg?" alt="Contributions welcome">\n</a>\n<a href="https://doi.org/10.5281/zenodo.10625407" target="_blank">\n    <img src="https://zenodo.org/badge/DOI/10.5281/zenodo.10625407.svg" alt="Zenodo">\n</a>\n<a href="https://github.com/pyOpenSci/software-review/issues/146" target="_blank">\n    <img src="https://tinyurl.com/y22nb8up?" alt="pyOpenSci">\n</a>\n<a style="border-width:0" href="https://doi.org/10.21105/joss.06490">\n  <img src="https://joss.theoj.org/papers/10.21105/joss.06490/status.svg" alt="DOI badge" >\n</a>\n\nCompare the structure of two [netCDF](https://www.unidata.ucar.edu/software/netcdf) files \nat the command line or via Python. `ncompare` generates a view of the matching and \nnon-matching groups and variables between two netCDF datasets.\n\nAllthough tailored for netCDF files, `ncompare`\nalso works with some [HDF5](https://www.hdfgroup.org/solutions/hdf5/) files \n(see [notes and known limitations](#notes-and-known-limitations)).\n\n\n## Installing\n\nThe latest release of `ncompare` can be installed with `mamba`, `conda` or `pip`:\n\n```bash\nmamba install -c conda-forge ncompare\n```\n```bash\nconda install -c conda-forge ncompare\n```\n```bash\npip install ncompare\n```\n\n## Usage Examples\n\n### At a command line:\nTo compare two netCDF files,\npass the filepaths for each of the two netCDF files directly to ncompare, as follows:\n\n```console\nncompare <netcdf file #1> <netcdf file #2>\n```\n\n<img src="https://github.com/nasa/ncompare/assets/114174502/1964096e-829d-4fe1-96a5-63581ade2d38" width="600" />\n\n\nWith an additional `--file-text` argument specified,\na common use of _ncompare_ may look like this example:\n\n```console\nncompare S001G01.nc S001G01_SUBSET.nc --file-text subset_comparison.txt\n```\n\n### In a Python kernel:\n\n```python\nfrom ncompare import compare\n\ntotal_number_of_differences = compare("<netcdf file 1>", "<netcdf file 2>", only_diffs=True,\n                                      show_chunks=True, show_attributes=True)\n```\n\n\n### More complete usage demonstrations, with example output, are shown in [this example notebook](https://ncompare.readthedocs.io/en/latest/example/ncompare-example-usage/).\n\n## Contributing\n\nContributions are welcome! For more information, see [CONTRIBUTING.md](CONTRIBUTING.md).\n_ncompare_ is licensed under the Apache License 2.0,\nwhich is included in the [LICENSE](LICENSE) file.\n\n\n### Developing\n\nDevelopment within this repository should occur on a feature branch.\nPull Requests (PRs) are created with a target of the `develop` branch before being reviewed and merged.\n\n### Installing locally\n\nFor local development, one can clone the repository and then use poetry or pip from the local directory:\n\n```console\ngit clone https://github.com/nasa/ncompare.git\n```\n\n###### (Option A) using poetry:\nii) Follow the instructions for installing `poetry` [here](https://python-poetry.org/docs/).\n\niii) Run ```poetry install``` from the repository directory.\n\n###### (Option B) using pip:\n\nii) Run ```pip install .``` from the repository directory.\n\n\n### Testing locally\n\nIf installed using a `poetry` environment, the tests can be run with:\n```console\npoetry run pytest tests\n```\n\nOr from another virtual environment, one can use:\n```console\npytest tests\n```\n\n### To run as a locally installed poetry module\n\n```console\npoetry run ncompare <netcdf file #1> <netcdf file #2>\n```\n\n\n## Why ncompare?\n\nThe `cdo` (climate data operators) tool\n[does not support netCDF4 groups](https://code.mpimet.mpg.de/boards/2/topics/12073).\nMoreover, `nco` operators\' `ncdiff` function computes value differences, but\n--- as far as the developers of this tool are aware ---\n`nco` does not have a simple function to show structural differences between NetCDF4 datasets.\n Note that `h5diff`, provided in the HDF5 software, can also be used to find differences.\nIn comparison to `h5diff`, `ncompare` is written and runnable in Python; `ncompare` provides _aligned_ and\n_colorized_ difference report for quicker assessments of groups, variable names, types, shapes, and attributes;\nand can generate report files formatted for other applications. However, note that\n`h5diff` provides comparison of some otherwise "hidden" hdf5 properties, such as _Netcdf4Dimid or _Netcdf4Coordinates,\nwhich are not currently assessed by `ncompare`.\n\n## Notes and known limitations\n\n- `ncompare` works successfully with select HDF5 files,\n  although it has not been tested extensively; therefore,\n  it would not be surprising to find additional limitations with other HDF files.\n- `ncompare` uses `xarray` to access the root-level dimensions.\nIn some cases, `xarray` will miss dimensions whose names do not also exist as variable names in the dataset\n  (also known as non-coordinate dimensions).\n- Some underlying HDF5 properties, such as _Netcdf4Dimid or _Netcdf4Coordinates, are not currently assesssed by `ncompare`.\n\n# Notices:\n\nCopyright 2023 United States Government as represented by the Administrator of the\nNational Aeronautics and Space Administration. All Rights Reserved.\n\nThis software calls the following third-party software,\nwhich is subject to the terms and conditions of its licensor,\nas applicable at the time of licensing.\nThe third-party software is not bundled with this software but may be available from the licensor.\n\nLicense hyperlinks are provided here for information purposes only.\n\n\n| Title    |                               license                               | link                                                          |\n|:---------|:-------------------------------------------------------------------:|:--------------------------------------------------------------|\n| colorama |                            BSD-3-Clause                             | https://opensource.org/licenses/BSD-3-Clause                  |\n| netCDF4  |                             MIT License                             | https://opensource.org/licenses/MIT                           |\n| numpy    |                            BSD-3-Clause                             | https://opensource.org/licenses/BSD-3-Clause                  |\n| openpyxl |                             MIT License                             | https://opensource.org/licenses/MIT                           |\n| xarray   |                     Apache License, version 2.0                     | https://www.apache.org/licenses/LICENSE-2.0                   |\n| Python   | Standard Library Python Software Foundation (PSF) License Agreement | https://docs.python.org/3/license.html#psf-licenseDisclaimers |\n\n\nThe ncompare: NetCDF structural comparison tool framework is licensed under the Apache License,\nVersion 2.0 (the "License");\nyou may not use this application except in compliance with the License.\nYou may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0.\n\nUnless required by applicable law or agreed to in writing,\nsoftware distributed under the License is distributed on an "AS IS" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and limitations under the License.\n\n---\nThis package is NASA Software Release Authorization (SRA) # LAR-20274-1\n',
    'author': 'Daniel Kaufman',
    'author_email': 'daniel.kaufman@nasa.gov',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/nasa/ncompare',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
